@@ -172,17 +172,24 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         return list(self.rates.keys())
 
     @staticmethod
-    def _unpack_stoichiometries(*, stoichiometries: Dict[str, int]) -> Tuple[List[str], List[str]]:
+    def _unpack_stoichiometries(*, stoichiometries: Dict[str, int]) -> Tuple[Dict[str, int], Dict[str, int]]:
         """Split stoichiometries into substrates and products."""
-        substrates = []
-        products = []
+        substrates = {}
+        products = {}
         for k, v in stoichiometries.items():
             if v < 0:
-                substrates.extend([k] * -v)
+                substrates[k] = -v
             else:
-                products.extend([k] * v)
+                products[k] = v
         return substrates, products
 
+    @staticmethod
+    def _stoichiometry_to_duplicate_list(*, stoichiometry: Dict[str, int]) -> List[str]:
+        l = []
+        for k, v in stoichiometry.items():
+            l.extend([k] * v)
+        return l
+
     @staticmethod
     def _add_label_influx_or_efflux(
         *,
@@ -222,19 +229,31 @@ class LinearLabelModel(_AbstractStoichiometricModel):
             warnings.warn(f"Overwriting reaction {rate_name}")
             self.remove_reaction(rate_name=rate_name)
 
-        base_substrates, base_products = self._unpack_stoichiometries(stoichiometries=stoichiometry)
-        substrates = [j for i in base_substrates for j in self.isotopomers[i]]
-        products = [j for i in base_products for j in self.isotopomers[i]]
+        substrates, products = self._unpack_stoichiometries(stoichiometries=stoichiometry)
+        self.add_reaction_from_substrates_and_products(rate_name, substrates, products, labelmap)
+
+    def add_reaction_from_substrates_and_products(
+        self,
+        rate_name: str,
+        substrates: Dict[str, int],
+        products: Dict[str, int],
+        labelmap: List[int],
+    ) -> None:
+        subs = self._stoichiometry_to_duplicate_list(stoichiometry=substrates)
+        prods = self._stoichiometry_to_duplicate_list(stoichiometry=products)
+
+        subs = [j for i in substrates for j in self.isotopomers[i]]
+        prods = [j for i in products for j in self.isotopomers[i]]
 
         self._add_label_influx_or_efflux(
             rate_name=rate_name,
-            substrates=substrates,
-            products=products,
+            substrates=subs,
+            products=prods,
             labelmap=labelmap,
         )
-        substrates = self._map_substrates_to_labelmap(substrates=substrates, labelmap=labelmap)
+        subs = self._map_substrates_to_labelmap(substrates=subs, labelmap=labelmap)
 
-        for i, (substrate, product) in enumerate(zip(substrates, products)):
+        for i, (substrate, product) in enumerate(zip(subs, prods)):
             self.add_stoichiometry(rate_name=f"{rate_name}__{i}", stoichiometry={substrate: -1, product: 1})
             self.add_rate(
                 rate_name=f"{rate_name}__{i}",
