@@ -29,7 +29,7 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
         y0: Optional[ArrayLike] = None,
         time: Optional[List[Array]] = None,
         results: Optional[List[Array]] = None,
-        parameters: List[Dict[str, float]] = None,
+        parameters: List[Dict[str, float]] | None = None,
     ) -> None:
         super().__init__(
             model=model,
@@ -178,20 +178,20 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
 
     def plot(
         self,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         """Plot all total concentrations."""
         compounds = sorted(
@@ -239,20 +239,20 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
         self,
         compound: str,
         relative: bool = True,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         """Plot label distribution of a compound."""
         if ylabel is None and relative:
