@@ -13,6 +13,7 @@ from typing import Any, Dict, List, Optional, Tuple, Type, Union, cast
 import numpy as np
 import pandas as pd
 from matplotlib.figure import Figure
+from scipy.optimize import minimize
 
 from ...core.utils import warning_on_one_line
 from ...typing import Array, ArrayLike, Axis
@@ -71,6 +72,50 @@ class _Simulate(_BaseRateSimulator[Model]):
             parameters=parameters,
         )
 
+    def fit_steady_state(
+        self,
+        p0: dict[str, float],
+        data: ArrayLike,
+    ) -> dict[str, float]:
+        par_names = list(p0.keys())
+        x0 = list(p0.values())
+        p_orig = self.model.parameters.copy()
+
+        def residual(par_values: ArrayLike, data: ArrayLike) -> float:
+            self.clear_results()
+            self.update_parameters(dict(zip(par_names, par_values)))
+            y_ss = self.simulate_to_steady_state()[1]
+            if y_ss is None:
+                return cast(float, np.inf)
+            return cast(float, np.sqrt(np.mean(np.square(data - y_ss.flatten()))))
+
+        res = dict(zip(par_names, minimize(residual, x0=x0, args=(data,)).x))
+        self.model.parameters = p_orig
+        return res
+
+    def fit_time_series(
+        self,
+        p0: dict[str, float],
+        data: ArrayLike,
+        time_points: ArrayLike,
+    ) -> dict[str, float]:
+        par_names = list(p0.keys())
+        x0 = list(p0.values())
+        p_orig = self.model.parameters.copy()
+        assert len(data) == len(time_points)
+
+        def residual(par_values: ArrayLike, data: ArrayLike, time_points: ArrayLike) -> float:
+            self.clear_results()
+            self.update_parameters(dict(zip(par_names, par_values)))
+            _, y = self.simulate(time_points=time_points)
+            if y is None:
+                return cast(float, np.inf)
+            return cast(float, np.sqrt(np.mean(np.square(data - y))))
+
+        res = dict(zip(par_names, minimize(residual, x0=x0, args=(data, time_points)).x))
+        self.model.parameters = p_orig
+        return res
+
     def plot(
         self,
         xlabel: str | None = None,
